class Articolo:
	def __init__(self, titolo, autore, collocazione):
		self.titolo = titolo
		self.autore = autore
		self.collocazione = collocazione
		self.tipo = ""
		self.durata = 30

	# valore predefinito per il prestito di un articolo
	#
	def durataPrestito(self):
		return self.durata

class Libro(Articolo):
	def __init__(self, titolo, autore, collocazione, genere):
		Articolo.__init__(self, titolo, autore, collocazione)
		self.genere = genere
		self.tipo = "libro"


class CD(Articolo):
	def __init__(self, titolo, autore, collocazione, genere):
		Articolo.__init__(self, titolo, autore, collocazione)
		self.tipo = "CD"
		self.genere = genere
		self.durata = 7

	# cd in prestito solo per una settimana
	

class Cliente:
	def __init__(self, nome, cognome):
		self.nome = nome
		self.cognome = cognome

	def bonusGiorniPrestito(self):
		return 0

	def isStudente(self):
		return False

class Studente(Cliente):
	def __init__(self, nome, cognome, nomeUniversita):
		Cliente.__init__(self, nome, cognome)
		self.nomeUniversita = nomeUniversita

	def bonusGiorniPrestito(self):
		return 10

	def isStudente(self):
		return True

class Prestito:
	def __init__(self, cliente, articolo, dataInizio):
		self.cliente = cliente
		self.articolo = articolo
		self.dataInizioPrestito = dataInizio

	def durataPrestito(self):
		return self.articolo.durataPrestito() + self.cliente.bonusGiorniPrestito()

class Biblioteca:
	def __init__(self, nome, luogo):
		self.nome = nome
		self.luogo = luogo
		
		self.prestiti = []
		self.clienti = []
		self.articoli = []
	
	def getListaArticoli(self):
		return self.articoli

	def getListaPrestiti(self):
		return self.prestiti

	def getListaClienti(self):
		return self.clienti

	def aggiungiStudente(self, nome, cognome, universita):
		s = Studente(nome, cognome, universita)
		self.clienti.append(s)

	def aggiungiCliente(self, nome, cognome):
		c = Cliente(nome, cognome)
		self.clienti.append(c)

	def aggiungiArticolo(self, collocazione,  titolo, autore, genere, tipo):
		articolo = None
		if tipo == "CD":
			articolo = CD(titolo, autore, collocazione, genere)
		elif tipo == "libro":
			articolo = Libro(titolo, autore, collocazione, genere)
		else:
			print("Tipo di articolo non supportato")

		if articolo != None:
			self.articoli.append(articolo)
	
	def cercaArticolo(self, titolo, autore):
		for articolo in self.articoli:
			if articolo.titolo == titolo and articolo.autore == autore:
				return articolo
		return None
	
	def cercaCliente(self, nome, cognome):
		for cliente in self.clienti:
			if cliente.nome == nome and cliente.cognome == cognome:
				return cliente
		return None

	
	def registraPrestito(self, titolo, autore, nomeCliente, cognomeCliente, dataPrestito):
		articolo = self.cercaArticolo(titolo, autore)
		cliente = self.cercaCliente(nomeCliente, cognomeCliente)

		if articolo != None and cliente != None:
			prestito = Prestito(cliente, articolo, dataPrestito)
			self.prestiti.append(prestito)
		else:
			print("articolo", titolo, autore, "non trovato oppure cliente", nomeCliente, cognomeCliente, "non iscritto alla biblioteca")


	
b = Biblioteca("Biblioteca Civica di Trieste", "Trieste")
b.aggiungiCliente("Giacomo", "Rossi")
b.aggiungiCliente("Bruno", "Verdi")
b.aggiungiStudente("Mario", "Resistenza", "Ingegneria")
b.aggiungiStudente("Federico", "Croce", "Filosofia")

b.aggiungiArticolo("CD06",  "The Wall", "Pink Floyd","Rock", "CD")
b.aggiungiArticolo("CD16",  "Sinfonia 13 Babi Yar", "Shostakovich", "Classica", "CD")

b.aggiungiArticolo("L207",  "L'interpretazione dei Sogni", "Freud", "Filosofia", "libro")
b.aggiungiArticolo("L208", "De sensu rerum et magia", "Campanella", "Filosofia", "libro")
b.aggiungiArticolo("L205", "Il mondo come volonta", "Schopenhauer", "Filosofia", "libro")

b.registraPrestito("The Wall", "Pink Floyd", "Giacomo", "Rossi", "12-01-2012")
b.registraPrestito( "Il mondo come volonta", "Schopenhauer", "Mario", "Resistenza", "8-12-2012")
b.registraPrestito( "L'interpretazione dei Sogni", "Freud", "Federico", "Croce", "9-12-2012")
b.registraPrestito("Sinfonia 13 Babi Yar", "Shostakovich", "Federico", "Croce", "9-12-2012")

# >>> sh = B.b.cercaArticolo("Sinfonia 13 Babi Yar", "Shostakovich")
# >>> sh.titolo
# 'Sinfonia 13 Babi Yar'
# >>> sh.autore
# 'Shostakovich'

#for prestito in B.b.getListaPrestiti():
#     print(prestito.articolo.titolo, ",", prestito.articolo.autore, ",", prestito.dataInizioPrestito, "-->", prestito.cliente.nome, prestito.cliente.cognome, " - durata:", prestito.durataPrestito(), prestito.articolo.collocazione)



	
